==> owncloud-8.1.0p2.tgz: owncloud/lib/l10n/zh_TW.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "無法寫入 config 目錄！",
    "This can usually be fixed by giving the webserver write access to the config directory" : "允許網頁伺服器寫入設定目錄通常可以解決這個問題",
    "See %s" : "見 %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "%s允許網頁伺服器寫入設定目錄%s通常可以解決這個問題",
    "Sample configuration detected" : "偵測到範本設定",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "看來您直接複製了範本設定來使用，這可能會毀掉你的安裝，請閱讀說明文件後對 config.php 進行適當的修改",
    "PHP %s or higher is required." : "需要 PHP %s 或更高版本",
    "Help" : "說明",
    "Personal" : "個人",
    "Users" : "使用者",
    "Admin" : "管理",
    "Recommended" : "建議",
    "No app name specified" : "沒有指定應用程式名稱",
    "Unknown filetype" : "未知的檔案類型",
    "Invalid image" : "無效的圖片",
    "today" : "今天",
    "yesterday" : "昨天",
    "last month" : "上個月",
    "_%n month ago_::_%n months ago_" : ["%n 個月前"],
    "last year" : "去年",
    "_%n hour ago_::_%n hours ago_" : ["%n 小時前"],
    "_%n minute ago_::_%n minutes ago_" : ["%n 分鐘前"],
    "seconds ago" : "幾秒前",
    "web services under your control" : "由您控制的網路服務",
    "App directory already exists" : "應用程式目錄已經存在",
    "Can't create app folder. Please fix permissions. %s" : "無法建立應用程式目錄，請檢查權限：%s",
    "No source specified when installing app" : "沒有指定應用程式安裝來源",
    "No href specified when installing app from http" : "從 http 安裝應用程式，找不到 href 屬性",
    "No path specified when installing app from local file" : "從本地檔案安裝應用程式時沒有指定路徑",
    "Archives of type %s are not supported" : "不支援 %s 格式的壓縮檔",
    "Failed to open archive when installing app" : "安裝應用程式時無法開啓壓縮檔",
    "App does not provide an info.xml file" : "應用程式沒有提供 info.xml 檔案",
    "App can't be installed because of not allowed code in the App" : "無法安裝應用程式因為在當中找到危險的代碼",
    "App can't be installed because it is not compatible with this version of ownCloud" : "無法安裝應用程式因為它和此版本的 ownCloud 不相容。",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "無法安裝應用程式，因為它包含了 <shipped>true</shipped> 標籤，在未發行的應用程式當中這是不允許的",
    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "無法安裝應用程式，因為它在 info.xml/version 宣告的版本與 app store 當中記載的版本不同",
    "Application is not enabled" : "應用程式未啟用",
    "Authentication error" : "認證錯誤",
    "Token expired. Please reload page." : "Token 過期，請重新整理頁面。",
    "Unknown user" : "未知的使用者",
    "%s enter the database username." : "%s 輸入資料庫使用者名稱。",
    "%s enter the database name." : "%s 輸入資料庫名稱。",
    "%s you may not use dots in the database name" : "%s 資料庫名稱不能包含小數點",
    "MS SQL username and/or password not valid: %s" : "MS SQL 使用者和/或密碼無效：%s",
    "You need to enter either an existing account or the administrator." : "您必須輸入一個現有的帳號或管理員帳號。",
    "MySQL/MariaDB username and/or password not valid" : "MySQL/MariaDB 使用者或密碼不正確",
    "DB Error: \"%s\"" : "資料庫錯誤：\"%s\"",
    "Offending command was: \"%s\"" : "有問題的指令是：\"%s\"",
    "MySQL/MariaDB user '%s'@'localhost' exists already." : "MySQL/MariaDB 使用者 '%s'@'localhost' 已經存在",
    "Drop this user from MySQL/MariaDB" : "自 MySQL/MariaDB 刪除這個使用者",
    "MySQL/MariaDB user '%s'@'%%' already exists" : "MySQL/MariaDB 使用者 '%s'@'%%' 已經存在",
    "Drop this user from MySQL/MariaDB." : "自 MySQL/MariaDB 刪除這個使用者",
    "Oracle connection could not be established" : "無法建立 Oracle 資料庫連線",
    "Oracle username and/or password not valid" : "Oracle 用戶名和/或密碼無效",
    "Offending command was: \"%s\", name: %s, password: %s" : "有問題的指令是：\"%s\" ，使用者：\"%s\"，密碼：\"%s\"",
    "PostgreSQL username and/or password not valid" : "PostgreSQL 用戶名和/或密碼無效",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "不支援 Mac OS X 而且 %s 在這個平台上面無法正常運作，請自行衡量風險！",
    "For the best results, please consider using a GNU/Linux server instead." : "請考慮使用 GNU/Linux 伺服器以取得最好的效果",
    "Set an admin username." : "設定管理員帳號。",
    "Set an admin password." : "設定管理員密碼。",
    "Can't create or write into the data directory %s" : "無法建立或寫入資料目錄 %s",
    "%s shared »%s« with you" : "%s 與您分享了 %s",
    "Sharing %s failed, because the file does not exist" : "分享 %s 失敗，因為檔案不存在",
    "You are not allowed to share %s" : "你不被允許分享 %s",
    "Sharing %s failed, because the user %s is the item owner" : "分享 %s 失敗，因為 %s 才是此項目的擁有者",
    "Sharing %s failed, because the user %s does not exist" : "分享 %s 失敗，因為使用者 %s 不存在",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "分享 %s 失敗，使用者 %s 並不屬於該項目擁有者 %s 所隸屬的任何一個群組",
    "Sharing %s failed, because this item is already shared with %s" : "分享 %s 失敗，因為此項目目前已經與 %s 分享",
    "Sharing %s failed, because the group %s does not exist" : "分享 %s 失敗，因為群組 %s 不存在",
    "Sharing %s failed, because %s is not a member of the group %s" : "分享 %s 失敗，因為 %s 不是群組 %s 的一員",
    "You need to provide a password to create a public link, only protected links are allowed" : "您必須為公開連結設定一組密碼，我們只允許受密碼保護的連結",
    "Sharing %s failed, because sharing with links is not allowed" : "分享 %s 失敗，因為目前不允許使用連結分享",
    "Share type %s is not valid for %s" : "分享類型 %s 對於 %s 來說無效",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "為 %s 設定權限失敗，因為欲設定的權限超出開放給 %s 的範圍",
    "Setting permissions for %s failed, because the item was not found" : "為 %s 設定權限失敗，因為找不到該項目",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "無法設定到期日，在分享之後，到期日不能設定為 %s 之後",
    "Cannot set expiration date. Expiration date is in the past" : "無法設定過去的日期為到期日",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "分享後端 %s 必須實作 OCP\\Share_Backend interface",
    "Sharing backend %s not found" : "找不到分享後端 %s",
    "Sharing backend for %s not found" : "找不到 %s 的分享後端",
    "Sharing %s failed, because the user %s is the original sharer" : "分享 %s 失敗，因為使用者 %s 即是原本的分享者",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "分享 %s 失敗，因為權限設定超出了授權給 %s 的範圍",
    "Sharing %s failed, because resharing is not allowed" : "分享 %s 失敗，不允許重複分享",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "分享 %s 失敗，因為 %s 的分享後端找不到它的來源",
    "Sharing %s failed, because the file could not be found in the file cache" : "分享 %s 失敗，因為在快取中找不到該檔案",
    "Could not find category \"%s\"" : "找不到分類：\"%s\"",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "使用者名稱當中只能包含下列字元：\"a-z\", \"A-Z\", \"0-9\", 和 \"_.@-\"",
    "A valid username must be provided" : "必須提供一個有效的用戶名",
    "A valid password must be provided" : "一定要提供一個有效的密碼",
    "The username is already being used" : "這個使用者名稱已經有人使用了",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "沒有安裝資料庫驅動程式 (sqlite, mysql, 或 postgresql)",
    "Cannot write into \"config\" directory" : "無法寫入 config 目錄",
    "Cannot write into \"apps\" directory" : "無法寫入 apps 目錄",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "通常藉由%s開放網頁伺服器對 apps 目錄的權限%s或是在設定檔中關閉 appstore 就可以修正這個問題",
    "Cannot create \"data\" directory (%s)" : "無法建立 data 目錄 (%s)",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "通常藉由<a href=\"%s\" target=\"_blank\">開放網頁伺服器對根目錄的權限</a>就可以修正權限問題",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "通常藉由%s開放網頁伺服器對根目錄的權限%s就可以修正權限問題",
    "Setting locale to %s failed" : "設定語系為 %s 失敗",
    "Please install one of these locales on your system and restart your webserver." : "請在系統中安裝這些語系的其中一個，然後重啓網頁伺服器",
    "Please ask your server administrator to install the module." : "請詢問系統管理員來安裝這些模組",
    "PHP module %s not installed." : "未安裝 PHP 模組 %s",
    "PHP modules have been installed, but they are still listed as missing?" : "你已經安裝了指定的 PHP 模組，可是還是顯示為找不到嗎？",
    "Please ask your server administrator to restart the web server." : "請聯絡您的系統管理員重新啟動網頁伺服器",
    "PostgreSQL >= 9 required" : "需要 PostgreSQL 版本 >= 9",
    "Please upgrade your database version" : "請升級您的資料庫版本",
    "Error occurred while checking PostgreSQL version" : "檢查 PostgreSQL 版本時發生錯誤",
    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "請確定您的 PostgreSQL 版本 >= 9，或是看看記錄檔是否有更詳細的訊息",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "請將該目錄權限設定為 0770 ，以免其他使用者讀取",
    "Data directory (%s) is readable by other users" : "資料目錄 (%s) 可以被其他使用者讀取",
    "Data directory (%s) is invalid" : "資料目錄 (%s) 無效",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "請確保資料目錄當中包含一個 .ocdata 的檔案",
    "Could not obtain lock type %d on \"%s\"." : "無法取得鎖定：類型 %d ，檔案 %s"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.7.tgz: owncloud/lib/l10n/zh_TW.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "無法寫入 config 目錄！",
    "This can usually be fixed by giving the webserver write access to the config directory" : "允許網頁伺服器寫入設定目錄通常可以解決這個問題",
    "See %s" : "見 %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "%s允許網頁伺服器寫入設定目錄%s通常可以解決這個問題",
    "Sample configuration detected" : "偵測到範本設定",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "看來您直接複製了範本設定來使用，這可能會毀掉你的安裝，請閱讀說明文件後對 config.php 進行適當的修改",
    "PHP %s or higher is required." : "需要 PHP %s 或更高版本",
    "PHP with a version lower than %s is required." : "需要 PHP 版本低於 %s ",
    "Following databases are supported: %s" : "這些資料庫支援: %s",
    "The command line tool %s could not be found" : "無法找到命令提示位元工具 %s",
    "The library %s is not available." : "套件庫 %s 無法使用",
    "Library %s with a version higher than %s is required - available version %s." : "需要套件庫 %s 版本高於 %s - 可使用的版本是 %s",
    "Library %s with a version lower than %s is required - available version %s." : "需要套件庫 %s 版本低於 %s - 可使用的版本是 %s",
    "Following platforms are supported: %s" : "這些平台支援: %s",
    "ownCloud %s or higher is required." : "需要ownCloud %s 或更高版本",
    "ownCloud %s or lower is required." : "需要ownCloud %s 或更低版本",
    "Unknown filetype" : "未知的檔案類型",
    "Invalid image" : "無效的圖片",
    "today" : "今天",
    "yesterday" : "昨天",
    "_%n day ago_::_%n days ago_" : ["%n 天前"],
    "last month" : "上個月",
    "_%n month ago_::_%n months ago_" : ["%n 個月前"],
    "last year" : "去年",
    "_%n year ago_::_%n years ago_" : ["%n 幾年前"],
    "_%n hour ago_::_%n hours ago_" : ["%n 小時前"],
    "_%n minute ago_::_%n minutes ago_" : ["%n 分鐘前"],
    "seconds ago" : "幾秒前",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "模組編號: %s 不存在，請在應用程式設定中開啟，或是聯絡系統管理員",
    "None" : "無",
    "Username and password" : "使用者帳號和密碼",
    "Username" : "使用者名稱",
    "Password" : "密碼",
    "Empty filename is not allowed" : "不允許空白的檔名",
    "Dot files are not allowed" : "不允許小數點開頭的檔案",
    "4-byte characters are not supported in file names" : "檔案名稱不支援4位元的字元",
    "File name is a reserved word" : "檔案名稱是預設保留字",
    "File name contains at least one invalid character" : "檔案名稱含有不合法的字元",
    "File name is too long" : "檔案名稱太長",
    "App directory already exists" : "應用程式目錄已經存在",
    "Can't create app folder. Please fix permissions. %s" : "無法建立應用程式目錄，請檢查權限：%s",
    "No source specified when installing app" : "沒有指定應用程式安裝來源",
    "No href specified when installing app from http" : "從 http 安裝應用程式，找不到 href 屬性",
    "No path specified when installing app from local file" : "從本地檔案安裝應用程式時沒有指定路徑",
    "Archives of type %s are not supported" : "不支援 %s 格式的壓縮檔",
    "Failed to open archive when installing app" : "安裝應用程式時無法開啓壓縮檔",
    "App does not provide an info.xml file" : "應用程式沒有提供 info.xml 檔案",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "無法驗證數位簽章，請聯絡 app 開發者，並檢查您的管理頁面",
    "App can't be installed because of not allowed code in the App" : "無法安裝應用程式因為在當中找到危險的代碼",
    "App can't be installed because it is not compatible with this version of ownCloud" : "無法安裝應用程式因為它和此版本的 ownCloud 不相容。",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "無法安裝應用程式，因為它包含了 <shipped>true</shipped> 標籤，在未發行的應用程式當中這是不允許的",
    "Apps" : "應用程式",
    "General" : "一般",
    "Storage" : "儲存區",
    "Security" : "安全性",
    "Encryption" : "加密",
    "Sharing" : "分享",
    "Search" : "搜尋",
    "Updates" : "更新",
    "%s enter the database username." : "%s 輸入資料庫使用者名稱。",
    "%s enter the database name." : "%s 輸入資料庫名稱。",
    "%s you may not use dots in the database name" : "%s 資料庫名稱不能包含小數點",
    "Oracle connection could not be established" : "無法建立 Oracle 資料庫連線",
    "Oracle username and/or password not valid" : "Oracle 用戶名和/或密碼無效",
    "DB Error: \"%s\"" : "資料庫錯誤：\"%s\"",
    "Offending command was: \"%s\"" : "有問題的指令是：\"%s\"",
    "You need to enter either an existing account or the administrator." : "您必須輸入一個現有的帳號或管理員帳號。",
    "Offending command was: \"%s\", name: %s, password: %s" : "有問題的指令是：\"%s\" ，使用者：\"%s\"，密碼：\"%s\"",
    "PostgreSQL username and/or password not valid" : "PostgreSQL 用戶名和/或密碼無效",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "不支援 Mac OS X 而且 %s 在這個平台上面無法正常運作，請自行衡量風險！",
    "For the best results, please consider using a GNU/Linux server instead." : "請考慮使用 GNU/Linux 伺服器以取得最好的效果",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "看起來 %s 是在32位元的PHP環境運行，而php.ini 有設置 open_basedir這個參數，當檔案大小超過4GB時，可能會發生問題，強烈建議您更改設定。",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "請移除 php.ini 中的 open_basedir 設定，或是改用64位元的PHP",
    "Set an admin username." : "設定管理員帳號。",
    "Set an admin password." : "設定管理員密碼。",
    "Can't create or write into the data directory %s" : "無法建立或寫入資料目錄 %s",
    "Invalid Federated Cloud ID" : "無效的雲端聯盟ID:",
    "%s shared »%s« with you" : "%s 與您分享了 %s",
    "%s via %s" : "%s 經由 %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "分享 %s失敗，不允許分享這樣的 %i 類別",
    "Sharing %s failed, because the file does not exist" : "分享 %s 失敗，因為檔案不存在",
    "You are not allowed to share %s" : "你不被允許分享 %s",
    "Sharing %s failed, because you can not share with yourself" : "分享 %s 失敗，不能分享給自己哦",
    "Sharing %s failed, because the user %s does not exist" : "分享 %s 失敗，因為使用者 %s 不存在",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "分享 %s 失敗，使用者 %s 並不屬於該項目擁有者 %s 所隸屬的任何一個群組",
    "Sharing %s failed, because this item is already shared with %s" : "分享 %s 失敗，因為此項目目前已經與 %s 分享",
    "Sharing %s failed, because this item is already shared with user %s" : "分享 %s 失敗，因為此項目目前已經與 %s 分享",
    "Sharing %s failed, because the group %s does not exist" : "分享 %s 失敗，因為群組 %s 不存在",
    "Sharing %s failed, because %s is not a member of the group %s" : "分享 %s 失敗，因為 %s 不是群組 %s 的一員",
    "You need to provide a password to create a public link, only protected links are allowed" : "您必須為公開連結設定一組密碼，我們只允許受密碼保護的連結",
    "Sharing %s failed, because sharing with links is not allowed" : "分享 %s 失敗，因為目前不允許使用連結分享",
    "Not allowed to create a federated share with the same user" : "不允許與同一個使用者建立聯盟式分享",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "分享%s失敗，找不到%s，或許目前無法連線到該伺服器",
    "Share type %s is not valid for %s" : "分享類型 %s 對於 %s 來說無效",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "為 %s 設定權限失敗，因為欲設定的權限超出開放給 %s 的範圍",
    "Setting permissions for %s failed, because the item was not found" : "為 %s 設定權限失敗，因為找不到該項目",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "無法設定到期日，在分享之後，到期日不能設定為 %s 之後",
    "Cannot set expiration date. Expiration date is in the past" : "無法設定過去的日期為到期日",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "到期日期不能空白，必須設定到期日才才能分享",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "分享後端 %s 必須實作 OCP\\Share_Backend interface",
    "Sharing backend %s not found" : "找不到分享後端 %s",
    "Sharing backend for %s not found" : "找不到 %s 的分享後端",
    "Sharing failed, because the user %s is the original sharer" : "分享失敗，因為使用者 %s 即是原本的分享者",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "分享 %s 失敗，因為權限設定超出了授權給 %s 的範圍",
    "Sharing %s failed, because resharing is not allowed" : "分享 %s 失敗，不允許重複分享",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "分享 %s 失敗，因為 %s 的分享後端找不到它的來源",
    "Sharing %s failed, because the file could not be found in the file cache" : "分享 %s 失敗，因為在快取中找不到該檔案",
    "Cannot increase permissions of %s" : "無法增加%s的權限",
    "Expiration date is in the past" : "到期日是之前的時間",
    "Cannot set expiration date more than %s days in the future" : "無法設定到期日超過未來%s天",
    "Could not find category \"%s\"" : "找不到分類：\"%s\"",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "使用者名稱當中只能包含下列字元：\"a-z\", \"A-Z\", \"0-9\", 和 \"_.@-'\"",
    "A valid username must be provided" : "必須提供一個有效的用戶名",
    "Username contains whitespace at the beginning or at the end" : "使用者名詞的開頭或結尾有空白",
    "A valid password must be provided" : "一定要提供一個有效的密碼",
    "The username is already being used" : "這個使用者名稱已經有人使用了",
    "Help" : "說明",
    "Settings" : "設定",
    "Users" : "使用者",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "應用程式 \"%s\" 無法被安裝，下列的相依性並不是完整的: %s",
    "web services under your control" : "由您控制的網路服務",
    "File is currently busy, please try again later" : "檔案目前忙碌中，請稍候再試",
    "Can't read file" : "無法讀取檔案",
    "Application is not enabled" : "應用程式未啟用",
    "Authentication error" : "認證錯誤",
    "Token expired. Please reload page." : "Token 過期，請重新整理頁面。",
    "Unknown user" : "未知的使用者",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "沒有安裝資料庫驅動程式 (sqlite, mysql, 或 postgresql)",
    "Cannot write into \"config\" directory" : "無法寫入 config 目錄",
    "Cannot write into \"apps\" directory" : "無法寫入 apps 目錄",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "通常藉由%s開放網頁伺服器對 apps 目錄的權限%s或是在設定檔中關閉 appstore 就可以修正這個問題",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "通常藉由%s開放網頁伺服器對根目錄的權限%s就可以修正權限問題",
    "Setting locale to %s failed" : "設定語系為 %s 失敗",
    "Please install one of these locales on your system and restart your webserver." : "請在系統中安裝這些語系的其中一個，然後重啓網頁伺服器",
    "Please ask your server administrator to install the module." : "請詢問系統管理員來安裝這些模組",
    "PHP module %s not installed." : "未安裝 PHP 模組 %s",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP設定值 \"%s\" 沒有被設定為 \"%s\"",
    "Adjusting this setting in php.ini will make ownCloud run again" : "調整php.ini裡的這項設定會讓ownCloud再次運行",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload 應該要被設定成 \"0\"而不是目前的設定 \"%s\" ",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "為了修正這個問題，請到php.ini將 <code>mbstring.func_overload</code> 的值改為 <code>0</code>",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP 已經設定成「剪除 inline doc block」模式，這將會使幾個核心應用程式無法使用",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "這大概是由快取或是加速器像是 Zend OPcache, eAccelerator 造成的",
    "PHP modules have been installed, but they are still listed as missing?" : "你已經安裝了指定的 PHP 模組，可是還是顯示為找不到嗎？",
    "Please ask your server administrator to restart the web server." : "請聯絡您的系統管理員重新啟動網頁伺服器",
    "PostgreSQL >= 9 required" : "需要 PostgreSQL 版本 >= 9",
    "Please upgrade your database version" : "請升級您的資料庫版本",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "請將該目錄權限設定為 0770 ，以免其他使用者讀取",
    "Check the value of \"datadirectory\" in your configuration" : "請檢查您的設定檔中 \"datadirectory\" 的值",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "請確保資料目錄當中包含一個 .ocdata 的檔案",
    "Could not obtain lock type %d on \"%s\"." : "無法取得鎖定：類型 %d ，檔案 %s",
    "Storage unauthorized. %s" : "儲存空間未經授權。%s",
    "Storage incomplete configuration. %s" : "儲存空間配置尚未完成。%s",
    "Storage connection error. %s" : "儲存空間連線錯誤。%s",
    "Storage connection timeout. %s" : "儲存空間連線逾時。%s"
},
"nplurals=1; plural=0;");
